@@ -16,16 +16,11 @@ import ipaddress
 import json
 import os
 import tempfile
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Union
-
+from typing import Any, Dict, List, Optional, Union
 
 import testinfra
 from testinfra.utils import cached_property
 
-
 __all__ = ["AnsibleRunner"]
 
 local = testinfra.get_host("local://")
@@ -73,28 +68,90 @@ def get_ansible_host(config, inventory, host, ssh_config=None, ssh_identity_file
         "paramiko_ssh",
         "local",
         "docker",
+        "community.docker.docker",
         "lxc",
         "lxd",
     ):
         # unhandled connection type, must use force_ansible=True
         return None
     connection = {
+        "community.docker.docker": "docker",
         "lxd": "lxc",
         "paramiko_ssh": "paramiko",
         "smart": "ssh",
     }.get(connection, connection)
-    testinfra_host = hostvars.get("ansible_host", host)
-    user = config.get("defaults", "remote_user", fallback=None)
-    if "ansible_user" in hostvars:
-        user = hostvars.get("ansible_user")
-    password = hostvars.get("ansible_ssh_pass")
-    port = config.get("defaults", "remote_port", fallback=None)
-    if "ansible_port" in hostvars:
-        port = hostvars.get("ansible_port")
+
+    options: Dict[str, Any] = {
+        "ansible_become": {
+            "ini": {
+                "section": "privilege_escalation",
+                "key": "become",
+            },
+            "environment": "ANSIBLE_BECOME",
+        },
+        "ansible_become_user": {
+            "ini": {
+                "section": "privilege_escalation",
+                "key": "become_user",
+            },
+            "environment": "ANSIBLE_BECOME_USER",
+        },
+        "ansible_port": {
+            "ini": {
+                "section": "defaults",
+                "key": "remote_port",
+            },
+            "environment": "ANSIBLE_REMOTE_PORT",
+        },
+        "ansible_ssh_common_args": {
+            "ini": {
+                "section": "ssh_connection",
+                "key": "ssh_common_args",
+            },
+            "environment": "ANSIBLE_SSH_COMMON_ARGS",
+        },
+        "ansible_ssh_extra_args": {
+            "ini": {
+                "section": "ssh_connection",
+                "key": "ssh_extra_args",
+            },
+            "environment": "ANSIBLE_SSH_EXTRA_ARGS",
+        },
+        "ansible_user": {
+            "ini": {
+                "section": "defaults",
+                "key": "remote_user",
+            },
+            "environment": "ANSIBLE_REMOTE_USER",
+        },
+    }
+
+    def get_config(name, default=None):
+        value = default
+        option = options.get(name, {})
+
+        ini = option.get("ini")
+        if ini:
+            value = config.get(ini["section"], ini["key"], fallback=default)
+
+        if name in hostvars:
+            value = hostvars[name]
+
+        var = option.get("environment")
+        if var and var in os.environ:
+            value = os.environ[var]
+
+        return value
+
+    testinfra_host = get_config("ansible_host", host)
+    user = get_config("ansible_user")
+    password = get_config("ansible_ssh_pass")
+    port = get_config("ansible_port")
+
     kwargs: Dict[str, Union[str, bool]] = {}
-    if hostvars.get("ansible_become", False):
+    if get_config("ansible_become", False):
         kwargs["sudo"] = True
-    kwargs["sudo_user"] = hostvars.get("ansible_become_user")
+    kwargs["sudo_user"] = get_config("ansible_become_user")
     if ssh_config is not None:
         kwargs["ssh_config"] = ssh_config
     if ssh_identity_file is not None:
@@ -108,14 +165,14 @@ def get_ansible_host(config, inventory, host, ssh_config=None, ssh_identity_file
     kwargs["ssh_extra_args"] = " ".join(
         [
             config.get("ssh_connection", "ssh_args", fallback=""),
-            hostvars.get("ansible_ssh_common_args", ""),
-            hostvars.get("ansible_ssh_extra_args", ""),
+            get_config("ansible_ssh_common_args", ""),
+            get_config("ansible_ssh_extra_args", ""),
         ]
     ).strip()
 
     spec = "{}://".format(connection)
 
-    # Fallback to user:pasword auth when identity file is not used
+    # Fallback to user:password auth when identity file is not used
     if user and password and not kwargs.get("ssh_identity_file"):
         spec += "{}:{}@".format(user, password)
     elif user:
@@ -277,7 +334,7 @@ class AnsibleRunner:
                 raise TypeError("Unsupported argument type '{}'.".format(opt_type))
         return " ".join(cli), cli_args
 
-    def run_module(self, host, module_name, module_args, **options):
+    def run_module(self, host, module_name, module_args, get_encoding=None, **options):
         cmd, args = "ansible --tree %s", []
         if self.inventory_file:
             cmd += " -i %s"
@@ -307,8 +364,15 @@ class AnsibleRunner:
                 raise RuntimeError(
                     "Error while running {}: {}".format(" ".join(cmd), out)
                 )
-            with open(os.path.join(d, files[0]), "r") as f:
-                return json.load(f)
+            fpath = os.path.join(d, files[0])
+            try:
+                with open(fpath, "r", encoding="ascii") as f:
+                    return json.load(f)
+            except UnicodeDecodeError:
+                if get_encoding is None:
+                    raise
+                with open(fpath, "r", encoding=get_encoding()) as f:
+                    return json.load(f)
 
     @classmethod
     def get_runner(cls, inventory):
